@@ -2,8 +2,8 @@
     function(x, data, xlab = "Simulated", ...)
 {
     require(lattice) || stop("requires package 'lattice'")
-    sim <- t(x$oecosimu$simulated)
     obs <- x$oecosimu$statistic
+    sim <- rbind(obs, t(x$oecosimu$simulated))
     nm <- names(obs)[col(sim)]
     densityplot( ~ as.vector(sim) | factor(nm, levels = unique(nm)),
                 xlab = xlab,
