@@ -1,4 +1,4 @@
-"print.mantel" <-
+`print.mantel` <-
   function (x, digits = max(3, getOption("digits") - 3), ...) 
 {
   cat("\n")
@@ -14,7 +14,7 @@
     cat("      Significance:", format.pval(x$signif), 
         "\n\n")
     out <- quantile(x$perm, c(0.9, 0.95, 0.975, 0.99))
-    cat("Empirical upper confidence limits of r:\n")
+    cat("Upper quantiles of permutations (null model):\n")
     print(out, digits = 3)
     cat("\nBased on", nperm, "permutations")
     if (!is.null(x$strata)) 
